/* SerializableTest.c generated by valac 0.34.6, the Vala compiler
 * generated from SerializableTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>


#define TYPE_SERIALIZABLE_TOMATO (serializable_tomato_get_type ())
#define SERIALIZABLE_TOMATO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_TOMATO, SerializableTomato))
#define SERIALIZABLE_TOMATO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_TOMATO, SerializableTomatoClass))
#define IS_SERIALIZABLE_TOMATO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_TOMATO))
#define IS_SERIALIZABLE_TOMATO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_TOMATO))
#define SERIALIZABLE_TOMATO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_TOMATO, SerializableTomatoClass))

typedef struct _SerializableTomato SerializableTomato;
typedef struct _SerializableTomatoClass SerializableTomatoClass;
typedef struct _SerializableTomatoPrivate SerializableTomatoPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_SERIALIZABLE_CAPSICUM (serializable_capsicum_get_type ())
#define SERIALIZABLE_CAPSICUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_CAPSICUM, SerializableCapsicum))
#define SERIALIZABLE_CAPSICUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_CAPSICUM, SerializableCapsicumClass))
#define IS_SERIALIZABLE_CAPSICUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_CAPSICUM))
#define IS_SERIALIZABLE_CAPSICUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_CAPSICUM))
#define SERIALIZABLE_CAPSICUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_CAPSICUM, SerializableCapsicumClass))

typedef struct _SerializableCapsicum SerializableCapsicum;
typedef struct _SerializableCapsicumClass SerializableCapsicumClass;
typedef struct _SerializableCapsicumPrivate SerializableCapsicumPrivate;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_SERIALIZABLE_BANANA (serializable_banana_get_type ())
#define SERIALIZABLE_BANANA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_BANANA, SerializableBanana))
#define SERIALIZABLE_BANANA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_BANANA, SerializableBananaClass))
#define IS_SERIALIZABLE_BANANA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_BANANA))
#define IS_SERIALIZABLE_BANANA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_BANANA))
#define SERIALIZABLE_BANANA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_BANANA, SerializableBananaClass))

typedef struct _SerializableBanana SerializableBanana;
typedef struct _SerializableBananaClass SerializableBananaClass;
typedef struct _SerializableBananaPrivate SerializableBananaPrivate;
#define _g_param_spec_unref0(var) ((var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL)))

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_TEST (serializable_test_get_type ())
#define SERIALIZABLE_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_TEST, SerializableTest))
#define SERIALIZABLE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_TEST, SerializableTestClass))
#define IS_SERIALIZABLE_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_TEST))
#define IS_SERIALIZABLE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_TEST))
#define SERIALIZABLE_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_TEST, SerializableTestClass))

typedef struct _SerializableTest SerializableTest;
typedef struct _SerializableTestClass SerializableTestClass;
typedef struct _SerializableTestPrivate SerializableTestPrivate;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SerializableTomato {
	GXmlSerializableObjectModel parent_instance;
	SerializableTomatoPrivate * priv;
	gint weight;
};

struct _SerializableTomatoClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableTomatoPrivate {
	gint _age;
	gint _height;
	gchar* _description;
};

struct _SerializableCapsicum {
	GXmlSerializableObjectModel parent_instance;
	SerializableCapsicumPrivate * priv;
	gint weight;
};

struct _SerializableCapsicumClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableCapsicumPrivate {
	gint _age;
	gint _height;
	GList* _ratings;
};

struct _SerializableBanana {
	GXmlSerializableObjectModel parent_instance;
	SerializableBananaPrivate * priv;
	gint public_field;
};

struct _SerializableBananaClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableBananaPrivate {
	gint private_field;
	gint _private_property;
	gint _public_property;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableTest {
	GXmlTest parent_instance;
	SerializableTestPrivate * priv;
};

struct _SerializableTestClass {
	GXmlTestClass parent_class;
};


static gpointer serializable_tomato_parent_class = NULL;
static gpointer serializable_capsicum_parent_class = NULL;
static gpointer serializable_banana_parent_class = NULL;
static gpointer serializable_test_parent_class = NULL;

GType serializable_tomato_get_type (void) G_GNUC_CONST;
#define SERIALIZABLE_TOMATO_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SERIALIZABLE_TOMATO, SerializableTomatoPrivate))
enum  {
	SERIALIZABLE_TOMATO_DUMMY_PROPERTY,
	SERIALIZABLE_TOMATO_HEIGHT,
	SERIALIZABLE_TOMATO_DESCRIPTION
};
SerializableTomato* serializable_tomato_new (gint weight, gint age, gint height, const gchar* description);
SerializableTomato* serializable_tomato_construct (GType object_type, gint weight, gint age, gint height, const gchar* description);
static void serializable_tomato_set_age (SerializableTomato* self, gint value);
void serializable_tomato_set_height (SerializableTomato* self, gint value);
void serializable_tomato_set_description (SerializableTomato* self, const gchar* value);
static gchar* serializable_tomato_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_tomato_real_to_string (GXmlSerializableObjectModel* base);
static gint serializable_tomato_get_age (SerializableTomato* self);
gint serializable_tomato_get_height (SerializableTomato* self);
const gchar* serializable_tomato_get_description (SerializableTomato* self);
gboolean serializable_tomato_equals (SerializableTomato* a, SerializableTomato* b);
static void serializable_tomato_finalize (GObject* obj);
static void _vala_serializable_tomato_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_serializable_tomato_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType serializable_capsicum_get_type (void) G_GNUC_CONST;
#define SERIALIZABLE_CAPSICUM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SERIALIZABLE_CAPSICUM, SerializableCapsicumPrivate))
enum  {
	SERIALIZABLE_CAPSICUM_DUMMY_PROPERTY,
	SERIALIZABLE_CAPSICUM_HEIGHT,
	SERIALIZABLE_CAPSICUM_RATINGS
};
static gchar* serializable_capsicum_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_capsicum_real_to_string (GXmlSerializableObjectModel* base);
static gint serializable_capsicum_get_age (SerializableCapsicum* self);
gint serializable_capsicum_get_height (SerializableCapsicum* self);
GList* serializable_capsicum_get_ratings (SerializableCapsicum* self);
SerializableCapsicum* serializable_capsicum_new (gint weight, gint age, gint height, GList* ratings);
SerializableCapsicum* serializable_capsicum_construct (GType object_type, gint weight, gint age, gint height, GList* ratings);
static void serializable_capsicum_set_age (SerializableCapsicum* self, gint value);
void serializable_capsicum_set_height (SerializableCapsicum* self, gint value);
void serializable_capsicum_set_ratings (SerializableCapsicum* self, GList* value);
static void serializable_capsicum_serialize_unknown_property_type (SerializableCapsicum* self, GXmlNode* elem, GParamSpec* prop, GXmlNode** node);
static void _serializable_capsicum_serialize_unknown_property_type_gxml_serializable_serialize_unknown_property_type (GXmlSerializable* _sender, GXmlNode* element, GParamSpec* prop, GXmlNode** node, gpointer self);
void serializable_capsicum_deserialize_unknown_property_type (SerializableCapsicum* self, GXmlNode* elem, GParamSpec* prop);
static void _serializable_capsicum_deserialize_unknown_property_type_gxml_serializable_deserialize_unknown_property_type (GXmlSerializable* _sender, GXmlNode* node, GParamSpec* prop, gpointer self);
static void serializable_capsicum_finalize (GObject* obj);
static void _vala_serializable_capsicum_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_serializable_capsicum_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType serializable_banana_get_type (void) G_GNUC_CONST;
#define SERIALIZABLE_BANANA_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SERIALIZABLE_BANANA, SerializableBananaPrivate))
enum  {
	SERIALIZABLE_BANANA_DUMMY_PROPERTY,
	SERIALIZABLE_BANANA_PUBLIC_PROPERTY
};
SerializableBanana* serializable_banana_new (gint private_field, gint public_field, gint private_property, gint public_property);
SerializableBanana* serializable_banana_construct (GType object_type, gint private_field, gint public_field, gint private_property, gint public_property);
static void serializable_banana_set_private_property (SerializableBanana* self, gint value);
void serializable_banana_set_public_property (SerializableBanana* self, gint value);
static gboolean serializable_banana_real_property_use_nick (GXmlSerializableObjectModel* base);
static gchar* serializable_banana_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_banana_real_to_string (GXmlSerializableObjectModel* base);
static gint serializable_banana_get_private_property (SerializableBanana* self);
gint serializable_banana_get_public_property (SerializableBanana* self);
gboolean serializable_banana_equals (SerializableBanana* a, SerializableBanana* b);
static GParamSpec** serializable_banana_real_list_serializable_properties (GXmlSerializableObjectModel* base, int* result_length1);
void serializable_banana_get_property_value (SerializableBanana* self, GParamSpec* spec, GValue* val);
void serializable_banana_set_property_value (SerializableBanana* self, GParamSpec* spec, GValue* val);
static void serializable_banana_finalize (GObject* obj);
static void _vala_serializable_banana_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_serializable_banana_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_test_get_type (void) G_GNUC_CONST;
enum  {
	SERIALIZABLE_TEST_DUMMY_PROPERTY
};
void serializable_test_add_tests (void);
static void __lambda6_ (void);
static void ___lambda6__gtest_func (void);
static void __lambda7_ (void);
static void ___lambda7__gtest_func (void);
static void __lambda8_ (void);
static void ___lambda8__gtest_func (void);
SerializableTest* serializable_test_new (void);
SerializableTest* serializable_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


SerializableTomato* serializable_tomato_construct (GType object_type, gint weight, gint age, gint height, const gchar* description) {
	SerializableTomato * self = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (description != NULL, NULL);
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableTomato*) gxml_serializable_object_model_construct (object_type);
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = weight;
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->weight = _tmp0_;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = age;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_tomato_set_age (self, _tmp1_);
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = height;
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_tomato_set_height (self, _tmp2_);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = description;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_tomato_set_description (self, _tmp3_);
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return self;
#line 275 "SerializableTest.c"
}


SerializableTomato* serializable_tomato_new (gint weight, gint age, gint height, const gchar* description) {
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return serializable_tomato_construct (TYPE_SERIALIZABLE_TOMATO, weight, age, height, description);
#line 282 "SerializableTest.c"
}


static gchar* serializable_tomato_real_node_name (GXmlSerializableObjectModel* base) {
	SerializableTomato * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableTomato*) base;
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = g_strdup ("Tomato");
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 298 "SerializableTest.c"
}


static gchar* serializable_tomato_real_to_string (GXmlSerializableObjectModel* base) {
	SerializableTomato * self;
	gchar* result = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableTomato*) base;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->weight;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = self->priv->_age;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = self->priv->_height;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = self->priv->_description;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = g_strdup_printf ("SerializableTomato {weight:%d, age:%d, height:%d, description:%s}", _tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp4_;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 326 "SerializableTest.c"
}


gboolean serializable_tomato_equals (SerializableTomato* a, SerializableTomato* b) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	SerializableTomato* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	SerializableTomato* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gboolean same = FALSE;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (a != NULL, FALSE);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (b != NULL, FALSE);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = a;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = _tmp3_->weight;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_ = b;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp6_ = _tmp5_->weight;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp4_ == _tmp6_) {
#line 354 "SerializableTest.c"
		SerializableTomato* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		SerializableTomato* _tmp9_ = NULL;
		gint _tmp10_ = 0;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp7_ = a;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp8_ = _tmp7_->priv->_age;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp9_ = b;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp10_ = _tmp9_->priv->_age;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp2_ = _tmp8_ == _tmp10_;
#line 369 "SerializableTest.c"
	} else {
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp2_ = FALSE;
#line 373 "SerializableTest.c"
	}
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp2_) {
#line 377 "SerializableTest.c"
		SerializableTomato* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		SerializableTomato* _tmp13_ = NULL;
		gint _tmp14_ = 0;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp11_ = a;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp12_ = _tmp11_->priv->_height;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp13_ = b;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp14_ = _tmp13_->priv->_height;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp1_ = _tmp12_ == _tmp14_;
#line 392 "SerializableTest.c"
	} else {
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp1_ = FALSE;
#line 396 "SerializableTest.c"
	}
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp1_) {
#line 400 "SerializableTest.c"
		SerializableTomato* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		SerializableTomato* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp15_ = a;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp16_ = _tmp15_->priv->_description;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp17_ = b;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp18_ = _tmp17_->priv->_description;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp0_ = g_strcmp0 (_tmp16_, _tmp18_) == 0;
#line 415 "SerializableTest.c"
	} else {
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp0_ = FALSE;
#line 419 "SerializableTest.c"
	}
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	same = _tmp0_;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = same;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 427 "SerializableTest.c"
}


static gint serializable_tomato_get_age (SerializableTomato* self) {
	gint result;
	gint _tmp0_ = 0;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->_age;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 442 "SerializableTest.c"
}


static void serializable_tomato_set_age (SerializableTomato* self, gint value) {
	gint _tmp0_ = 0;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = value;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->_age = _tmp0_;
#line 454 "SerializableTest.c"
}


gint serializable_tomato_get_height (SerializableTomato* self) {
	gint result;
	gint _tmp0_ = 0;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->_height;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 469 "SerializableTest.c"
}


void serializable_tomato_set_height (SerializableTomato* self, gint value) {
	gint _tmp0_ = 0;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = value;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->_height = _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_notify ((GObject *) self, "height");
#line 483 "SerializableTest.c"
}


const gchar* serializable_tomato_get_description (SerializableTomato* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->_description;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 498 "SerializableTest.c"
}


void serializable_tomato_set_description (SerializableTomato* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = value;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_free0 (self->priv->_description);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->_description = _tmp1_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_notify ((GObject *) self, "description");
#line 517 "SerializableTest.c"
}


static void serializable_tomato_class_init (SerializableTomatoClass * klass) {
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_tomato_parent_class = g_type_class_peek_parent (klass);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_type_class_add_private (klass, sizeof (SerializableTomatoPrivate));
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_tomato_real_node_name;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_tomato_real_to_string;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_tomato_get_property;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_tomato_set_property;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_tomato_finalize;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_TOMATO_HEIGHT, g_param_spec_int ("height", "height", "height", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_TOMATO_DESCRIPTION, g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 540 "SerializableTest.c"
}


static void serializable_tomato_instance_init (SerializableTomato * self) {
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv = SERIALIZABLE_TOMATO_GET_PRIVATE (self);
#line 547 "SerializableTest.c"
}


static void serializable_tomato_finalize (GObject* obj) {
	SerializableTomato * self;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SERIALIZABLE_TOMATO, SerializableTomato);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_free0 (self->priv->_description);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (serializable_tomato_parent_class)->finalize (obj);
#line 559 "SerializableTest.c"
}


/**
 *
 *  GXml.Serializable.SerializableTest
 *
 *  Authors:
 *
 *       Richard Schwarting <aquarichy@gmail.com>
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *  Copyright (C) 2011-2013  Richard Schwarting <aquarichy@gmail.com>
 *  Copyright (c) 2013-2016 Daniel Espinosa <esodan@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType serializable_tomato_get_type (void) {
	static volatile gsize serializable_tomato_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_tomato_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableTomatoClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_tomato_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableTomato), 0, (GInstanceInitFunc) serializable_tomato_instance_init, NULL };
		GType serializable_tomato_type_id;
		serializable_tomato_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableTomato", &g_define_type_info, 0);
		g_once_init_leave (&serializable_tomato_type_id__volatile, serializable_tomato_type_id);
	}
	return serializable_tomato_type_id__volatile;
}


static void _vala_serializable_tomato_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SerializableTomato * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SERIALIZABLE_TOMATO, SerializableTomato);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	switch (property_id) {
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_TOMATO_HEIGHT:
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_value_set_int (value, serializable_tomato_get_height (self));
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_TOMATO_DESCRIPTION:
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_value_set_string (value, serializable_tomato_get_description (self));
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 617 "SerializableTest.c"
		default:
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 623 "SerializableTest.c"
	}
}


static void _vala_serializable_tomato_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SerializableTomato * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SERIALIZABLE_TOMATO, SerializableTomato);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	switch (property_id) {
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_TOMATO_HEIGHT:
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		serializable_tomato_set_height (self, g_value_get_int (value));
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_TOMATO_DESCRIPTION:
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		serializable_tomato_set_description (self, g_value_get_string (value));
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 645 "SerializableTest.c"
		default:
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 651 "SerializableTest.c"
	}
}


static gchar* serializable_capsicum_real_node_name (GXmlSerializableObjectModel* base) {
	SerializableCapsicum * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableCapsicum*) base;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = g_strdup ("Capsicum");
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 668 "SerializableTest.c"
}


static gchar* serializable_capsicum_real_to_string (GXmlSerializableObjectModel* base) {
	SerializableCapsicum * self;
	gchar* result = NULL;
	gchar* str = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gchar* _tmp3_ = NULL;
	GList* _tmp4_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableCapsicum*) base;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->weight;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = self->priv->_age;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = self->priv->_height;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = g_strdup_printf ("SerializableCapsicum {weight:%d, age:%d, height:%d, ratings:", _tmp0_, _tmp1_, _tmp2_);
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	str = _tmp3_;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = self->priv->_ratings;
#line 697 "SerializableTest.c"
	{
		GList* rating_collection = NULL;
		GList* rating_it = NULL;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		rating_collection = _tmp4_;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		for (rating_it = rating_collection; rating_it != NULL; rating_it = rating_it->next) {
#line 705 "SerializableTest.c"
			gint rating = 0;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			rating = (gint) ((gintptr) rating_it->data);
#line 709 "SerializableTest.c"
			{
				const gchar* _tmp5_ = NULL;
				gint _tmp6_ = 0;
				gchar* _tmp7_ = NULL;
				gchar* _tmp8_ = NULL;
				gchar* _tmp9_ = NULL;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp5_ = str;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp6_ = rating;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp7_ = g_strdup_printf ("%d ", _tmp6_);
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp8_ = _tmp7_;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp9_ = g_strconcat (_tmp5_, _tmp8_, NULL);
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_g_free0 (str);
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				str = _tmp9_;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_g_free0 (_tmp8_);
#line 732 "SerializableTest.c"
			}
		}
	}
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp10_ = str;
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp11_ = g_strconcat (_tmp10_, "}", NULL);
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_free0 (str);
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	str = _tmp11_;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = str;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 748 "SerializableTest.c"
}


static void _serializable_capsicum_serialize_unknown_property_type_gxml_serializable_serialize_unknown_property_type (GXmlSerializable* _sender, GXmlNode* element, GParamSpec* prop, GXmlNode** node, gpointer self) {
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_capsicum_serialize_unknown_property_type ((SerializableCapsicum*) self, element, prop, node);
#line 755 "SerializableTest.c"
}


static void _serializable_capsicum_deserialize_unknown_property_type_gxml_serializable_deserialize_unknown_property_type (GXmlSerializable* _sender, GXmlNode* node, GParamSpec* prop, gpointer self) {
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_capsicum_deserialize_unknown_property_type ((SerializableCapsicum*) self, node, prop);
#line 762 "SerializableTest.c"
}


SerializableCapsicum* serializable_capsicum_construct (GType object_type, gint weight, gint age, gint height, GList* ratings) {
	SerializableCapsicum * self = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	GList* _tmp3_ = NULL;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableCapsicum*) gxml_serializable_object_model_construct (object_type);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = weight;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->weight = _tmp0_;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = age;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_capsicum_set_age (self, _tmp1_);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = height;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_capsicum_set_height (self, _tmp2_);
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = ratings;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_capsicum_set_ratings (self, _tmp3_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, GXML_TYPE_SERIALIZABLE, GXmlSerializable), "serialize-unknown-property-type", (GCallback) _serializable_capsicum_serialize_unknown_property_type_gxml_serializable_serialize_unknown_property_type, self, 0);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, GXML_TYPE_SERIALIZABLE, GXmlSerializable), "deserialize-unknown-property-type", (GCallback) _serializable_capsicum_deserialize_unknown_property_type_gxml_serializable_deserialize_unknown_property_type, self, 0);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return self;
#line 796 "SerializableTest.c"
}


SerializableCapsicum* serializable_capsicum_new (gint weight, gint age, gint height, GList* ratings) {
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return serializable_capsicum_construct (TYPE_SERIALIZABLE_CAPSICUM, weight, age, height, ratings);
#line 803 "SerializableTest.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 810 "SerializableTest.c"
}


static gboolean int64_try_parse (const gchar* str, gint64* _result_) {
	gint64 _vala_result = 0LL;
	gboolean result = FALSE;
	gchar* endptr = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gint64 _tmp2_ = 0LL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
#line 684 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (str != NULL, FALSE);
#line 686 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 686 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp2_ = g_ascii_strtoll (_tmp0_, &_tmp1_, (guint) 0);
#line 686 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	endptr = _tmp1_;
#line 686 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_vala_result = _tmp2_;
#line 687 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp3_ = endptr;
#line 687 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp4_ = str;
#line 687 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp5_ = str;
#line 687 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp6_ = strlen (_tmp5_);
#line 687 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp7_ = _tmp6_;
#line 687 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp3_ == (((gchar*) _tmp4_) + _tmp7_)) {
#line 688 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		result = TRUE;
#line 688 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		if (_result_) {
#line 688 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
			*_result_ = _vala_result;
#line 854 "SerializableTest.c"
		}
#line 688 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		return result;
#line 858 "SerializableTest.c"
	} else {
#line 690 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		result = FALSE;
#line 690 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		if (_result_) {
#line 690 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
			*_result_ = _vala_result;
#line 866 "SerializableTest.c"
		}
#line 690 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		return result;
#line 870 "SerializableTest.c"
	}
#line 684 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_result_) {
#line 684 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		*_result_ = _vala_result;
#line 876 "SerializableTest.c"
	}
}


void serializable_capsicum_deserialize_unknown_property_type (SerializableCapsicum* self, GXmlNode* elem, GParamSpec* prop) {
	GXmlNode* element = NULL;
	GXmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	GValue outvalue = {0};
	GValue _tmp2_ = {0};
	GParamSpec* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GQuark _tmp7_ = 0U;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp6_label0 = 0;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (elem != NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (prop != NULL);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = elem;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_NODE, GXmlNode));
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	element = _tmp1_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_value_init (&_tmp2_, G_TYPE_INT);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	outvalue = _tmp2_;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = prop;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = _tmp3_->name;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_ = _tmp4_;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp7_ = (NULL == _tmp5_) ? 0 : g_quark_from_string (_tmp5_);
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp7_ == ((0 != _tmp6_label0) ? _tmp6_label0 : (_tmp6_label0 = g_quark_from_static_string ("ratings")))) {
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 921 "SerializableTest.c"
			default:
			{
				GList* _tmp8_ = NULL;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp8_ = NULL;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				serializable_capsicum_set_ratings (self, _tmp8_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_g_list_free0 (_tmp8_);
#line 931 "SerializableTest.c"
				{
					GeeBidirList* _rating_list = NULL;
					GeeBidirList* _tmp9_ = NULL;
					GeeBidirList* _tmp10_ = NULL;
					gint _rating_size = 0;
					GeeBidirList* _tmp11_ = NULL;
					gint _tmp12_ = 0;
					gint _tmp13_ = 0;
					gint _rating_index = 0;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_tmp9_ = gxml_node_get_children_nodes (element);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_tmp10_ = _tmp9_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_rating_list = _tmp10_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_tmp11_ = _rating_list;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_tmp12_ = gee_collection_get_size ((GeeCollection*) _tmp11_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_tmp13_ = _tmp12_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_rating_size = _tmp13_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_rating_index = -1;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					while (TRUE) {
#line 959 "SerializableTest.c"
						gint _tmp14_ = 0;
						gint _tmp15_ = 0;
						gint _tmp16_ = 0;
						GXmlNode* rating = NULL;
						GeeBidirList* _tmp17_ = NULL;
						gint _tmp18_ = 0;
						gpointer _tmp19_ = NULL;
						GXmlNode* _tmp20_ = NULL;
						gchar* _tmp21_ = NULL;
						gchar* _tmp22_ = NULL;
						gchar* _tmp23_ = NULL;
						gint64 _tmp24_ = 0LL;
						GValue _tmp25_ = {0};
						GList* _tmp26_ = NULL;
						gint64 _tmp27_ = 0LL;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp14_ = _rating_index;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_rating_index = _tmp14_ + 1;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp15_ = _rating_index;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp16_ = _rating_size;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						if (!(_tmp15_ < _tmp16_)) {
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
							break;
#line 987 "SerializableTest.c"
						}
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp17_ = _rating_list;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp18_ = _rating_index;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp19_ = gee_list_get ((GeeList*) _tmp17_, _tmp18_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						rating = (GXmlNode*) _tmp19_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp20_ = rating;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp21_ = gxml_element_get_content ((GXmlElement*) G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp22_ = _tmp21_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp23_ = _tmp22_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						int64_try_parse (_tmp23_, &_tmp24_);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						G_IS_VALUE (&outvalue) ? (g_value_unset (&outvalue), NULL) : NULL;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						g_value_init (&_tmp25_, G_TYPE_INT64);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						g_value_set_int64 (&_tmp25_, _tmp24_);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						outvalue = _tmp25_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_g_free0 (_tmp23_);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp26_ = self->priv->_ratings;
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_tmp27_ = g_value_get_int64 (&outvalue);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						serializable_capsicum_set_ratings (self, g_list_append (_tmp26_, (gpointer) ((gintptr) ((gint) _tmp27_))));
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						_g_object_unref0 (rating);
#line 1025 "SerializableTest.c"
					}
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_g_object_unref0 (_rating_list);
#line 1029 "SerializableTest.c"
				}
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 1033 "SerializableTest.c"
			}
		}
	} else {
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1039 "SerializableTest.c"
			default:
			{
				GParamSpec* _tmp28_ = NULL;
				const gchar* _tmp29_ = NULL;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp28_ = prop;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp29_ = _tmp28_->name;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				g_test_message ("Wasn't expecting the SerializableCapsicum property '%s'", _tmp29_);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				g_assert_not_reached ();
#line 1052 "SerializableTest.c"
			}
		}
	}
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_IS_VALUE (&outvalue) ? (g_value_unset (&outvalue), NULL) : NULL;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_object_unref0 (element);
#line 1060 "SerializableTest.c"
}


static void serializable_capsicum_serialize_unknown_property_type (SerializableCapsicum* self, GXmlNode* elem, GParamSpec* prop, GXmlNode** node) {
	GXmlNode* _vala_node = NULL;
	GError * _inner_error_ = NULL;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (elem != NULL);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (prop != NULL);
#line 1073 "SerializableTest.c"
	{
		GXmlGElement* element = NULL;
		GXmlNode* _tmp0_ = NULL;
		GXmlGElement* _tmp1_ = NULL;
		GXmlDocument* doc = NULL;
		GXmlDocument* _tmp2_ = NULL;
		GXmlDocument* _tmp3_ = NULL;
		GXmlDocument* _tmp4_ = NULL;
		GParamSpec* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GQuark _tmp9_ = 0U;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		static GQuark _tmp8_label0 = 0;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp0_ = elem;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		element = _tmp1_;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp2_ = gxml_gnode_get_document ((GXmlGNode*) element);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp3_ = _tmp2_;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp4_ = _g_object_ref0 (_tmp3_);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		doc = _tmp4_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp5_ = prop;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp6_ = _tmp5_->name;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp7_ = _tmp6_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp9_ = (NULL == _tmp7_) ? 0 : g_quark_from_string (_tmp7_);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (_tmp9_ == ((0 != _tmp8_label0) ? _tmp8_label0 : (_tmp8_label0 = g_quark_from_static_string ("ratings")))) {
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			switch (0) {
#line 1114 "SerializableTest.c"
				default:
				{
					GList* _tmp10_ = NULL;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_tmp10_ = self->priv->_ratings;
#line 1120 "SerializableTest.c"
					{
						GList* rating_int_collection = NULL;
						GList* rating_int_it = NULL;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						rating_int_collection = _tmp10_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
						for (rating_int_it = rating_int_collection; rating_int_it != NULL; rating_int_it = rating_int_it->next) {
#line 1128 "SerializableTest.c"
							gint rating_int = 0;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
							rating_int = (gint) ((gintptr) rating_int_it->data);
#line 1132 "SerializableTest.c"
							{
								GXmlNode* _tmp11_ = NULL;
								GXmlNode* _tmp12_ = NULL;
								GXmlGElement* n = NULL;
								GXmlNode* _tmp13_ = NULL;
								GXmlGElement* _tmp14_ = NULL;
								gint _tmp15_ = 0;
								gchar* _tmp16_ = NULL;
								gchar* _tmp17_ = NULL;
								GXmlDomHTMLCollection* _tmp18_ = NULL;
								GXmlDomHTMLCollection* _tmp19_ = NULL;
								GXmlDomHTMLCollection* _tmp20_ = NULL;
								GXmlGElement* _tmp21_ = NULL;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp12_ = gxml_document_create_element (doc, "rating", &_inner_error_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp11_ = _tmp12_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
									_g_object_unref0 (doc);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
									_g_object_unref0 (element);
#line 1156 "SerializableTest.c"
									goto __catch8_g_error;
								}
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp13_ = _tmp11_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp11_ = NULL;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								n = G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp14_ = n;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp15_ = rating_int;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp16_ = g_strdup_printf ("%d", _tmp15_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp17_ = _tmp16_;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								gxml_element_set_content ((GXmlElement*) _tmp14_, _tmp17_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_g_free0 (_tmp17_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp18_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) element);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp19_ = _tmp18_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp20_ = _tmp19_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_tmp21_ = n;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								gee_collection_add ((GeeCollection*) _tmp20_, (GXmlDomElement*) _tmp21_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_g_object_unref0 (_tmp20_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_g_object_unref0 (n);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
								_g_object_unref0 (_tmp11_);
#line 1193 "SerializableTest.c"
							}
						}
					}
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					break;
#line 1199 "SerializableTest.c"
				}
			}
		} else {
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			switch (0) {
#line 1205 "SerializableTest.c"
				default:
				{
					GParamSpec* _tmp22_ = NULL;
					const gchar* _tmp23_ = NULL;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_tmp22_ = prop;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					_tmp23_ = _tmp22_->name;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					g_test_message ("Wasn't expecting the SerializableCapsicum property '%s'", _tmp23_);
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
					g_assert_not_reached ();
#line 1218 "SerializableTest.c"
				}
			}
		}
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (doc);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (element);
#line 1226 "SerializableTest.c"
	}
	goto __finally8;
	__catch8_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		e = _inner_error_;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_inner_error_ = NULL;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp24_ = e->message;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp25_ = g_strconcat ("Error: ", _tmp24_, NULL);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp26_ = _tmp25_;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_message ("SerializableTest.vala:120: %s", _tmp26_);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_free0 (_tmp26_);
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_assert_not_reached ();
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_error_free0 (e);
#line 1253 "SerializableTest.c"
	}
	__finally8:
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_clear_error (&_inner_error_);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		return;
#line 1264 "SerializableTest.c"
	}
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (node) {
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		*node = _vala_node;
#line 1270 "SerializableTest.c"
	} else {
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (_vala_node);
#line 1274 "SerializableTest.c"
	}
}


static gint serializable_capsicum_get_age (SerializableCapsicum* self) {
	gint result;
	gint _tmp0_ = 0;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->_age;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 1290 "SerializableTest.c"
}


static void serializable_capsicum_set_age (SerializableCapsicum* self, gint value) {
	gint _tmp0_ = 0;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = value;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->_age = _tmp0_;
#line 1302 "SerializableTest.c"
}


gint serializable_capsicum_get_height (SerializableCapsicum* self) {
	gint result;
	gint _tmp0_ = 0;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->_height;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 1317 "SerializableTest.c"
}


void serializable_capsicum_set_height (SerializableCapsicum* self, gint value) {
	gint _tmp0_ = 0;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = value;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->_height = _tmp0_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_notify ((GObject *) self, "height");
#line 1331 "SerializableTest.c"
}


GList* serializable_capsicum_get_ratings (SerializableCapsicum* self) {
	GList* result;
	GList* _tmp0_ = NULL;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->_ratings;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 1346 "SerializableTest.c"
}


void serializable_capsicum_set_ratings (SerializableCapsicum* self, GList* value) {
	GList* _tmp0_ = NULL;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = value;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->_ratings = _tmp0_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_notify ((GObject *) self, "ratings");
#line 1360 "SerializableTest.c"
}


static void serializable_capsicum_class_init (SerializableCapsicumClass * klass) {
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_capsicum_parent_class = g_type_class_peek_parent (klass);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_type_class_add_private (klass, sizeof (SerializableCapsicumPrivate));
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_capsicum_real_node_name;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_capsicum_real_to_string;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_capsicum_get_property;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_capsicum_set_property;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_capsicum_finalize;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_CAPSICUM_HEIGHT, g_param_spec_int ("height", "height", "height", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_CAPSICUM_RATINGS, g_param_spec_pointer ("ratings", "ratings", "ratings", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1383 "SerializableTest.c"
}


static void serializable_capsicum_instance_init (SerializableCapsicum * self) {
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv = SERIALIZABLE_CAPSICUM_GET_PRIVATE (self);
#line 1390 "SerializableTest.c"
}


static void serializable_capsicum_finalize (GObject* obj) {
	SerializableCapsicum * self;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SERIALIZABLE_CAPSICUM, SerializableCapsicum);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (serializable_capsicum_parent_class)->finalize (obj);
#line 1400 "SerializableTest.c"
}


GType serializable_capsicum_get_type (void) {
	static volatile gsize serializable_capsicum_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_capsicum_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableCapsicumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_capsicum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableCapsicum), 0, (GInstanceInitFunc) serializable_capsicum_instance_init, NULL };
		GType serializable_capsicum_type_id;
		serializable_capsicum_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableCapsicum", &g_define_type_info, 0);
		g_once_init_leave (&serializable_capsicum_type_id__volatile, serializable_capsicum_type_id);
	}
	return serializable_capsicum_type_id__volatile;
}


static void _vala_serializable_capsicum_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SerializableCapsicum * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SERIALIZABLE_CAPSICUM, SerializableCapsicum);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	switch (property_id) {
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_CAPSICUM_HEIGHT:
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_value_set_int (value, serializable_capsicum_get_height (self));
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_CAPSICUM_RATINGS:
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_value_set_pointer (value, serializable_capsicum_get_ratings (self));
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 1433 "SerializableTest.c"
		default:
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 1439 "SerializableTest.c"
	}
}


static void _vala_serializable_capsicum_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SerializableCapsicum * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SERIALIZABLE_CAPSICUM, SerializableCapsicum);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	switch (property_id) {
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_CAPSICUM_HEIGHT:
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		serializable_capsicum_set_height (self, g_value_get_int (value));
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_CAPSICUM_RATINGS:
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		serializable_capsicum_set_ratings (self, g_value_get_pointer (value));
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 1461 "SerializableTest.c"
		default:
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 1467 "SerializableTest.c"
	}
}


SerializableBanana* serializable_banana_construct (GType object_type, gint private_field, gint public_field, gint private_property, gint public_property) {
	SerializableBanana * self = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableBanana*) gxml_serializable_object_model_construct (object_type);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = private_field;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->private_field = _tmp0_;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = public_field;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->public_field = _tmp1_;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = private_property;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_banana_set_private_property (self, _tmp2_);
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = public_property;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_banana_set_public_property (self, _tmp3_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return self;
#line 1498 "SerializableTest.c"
}


SerializableBanana* serializable_banana_new (gint private_field, gint public_field, gint private_property, gint public_property) {
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return serializable_banana_construct (TYPE_SERIALIZABLE_BANANA, private_field, public_field, private_property, public_property);
#line 1505 "SerializableTest.c"
}


static gboolean serializable_banana_real_property_use_nick (GXmlSerializableObjectModel* base) {
	SerializableBanana * self;
	gboolean result = FALSE;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableBanana*) base;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = TRUE;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 1518 "SerializableTest.c"
}


static gchar* serializable_banana_real_node_name (GXmlSerializableObjectModel* base) {
	SerializableBanana * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableBanana*) base;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = g_strdup ("Banana");
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 1534 "SerializableTest.c"
}


static gchar* serializable_banana_real_to_string (GXmlSerializableObjectModel* base) {
	SerializableBanana * self;
	gchar* result = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	gchar* _tmp4_ = NULL;
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableBanana*) base;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->private_field;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = self->public_field;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = self->priv->_private_property;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = self->priv->_public_property;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = g_strdup_printf ("SerializableBanana {private_field:%d, public_field:%d, private_propert" \
"y:%d, public_property:%d}", _tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp4_;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 1562 "SerializableTest.c"
}


gboolean serializable_banana_equals (SerializableBanana* a, SerializableBanana* b) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	SerializableBanana* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	SerializableBanana* _tmp5_ = NULL;
	gint _tmp6_ = 0;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (a != NULL, FALSE);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (b != NULL, FALSE);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = a;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = _tmp3_->priv->private_field;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_ = b;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp6_ = _tmp5_->priv->private_field;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp4_ == _tmp6_) {
#line 1589 "SerializableTest.c"
		SerializableBanana* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		SerializableBanana* _tmp9_ = NULL;
		gint _tmp10_ = 0;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp7_ = a;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp8_ = _tmp7_->public_field;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp9_ = b;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp10_ = _tmp9_->public_field;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp2_ = _tmp8_ == _tmp10_;
#line 1604 "SerializableTest.c"
	} else {
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp2_ = FALSE;
#line 1608 "SerializableTest.c"
	}
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp2_) {
#line 1612 "SerializableTest.c"
		SerializableBanana* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		SerializableBanana* _tmp13_ = NULL;
		gint _tmp14_ = 0;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp11_ = a;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp12_ = _tmp11_->priv->_private_property;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp13_ = b;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp14_ = _tmp13_->priv->_private_property;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp1_ = _tmp12_ == _tmp14_;
#line 1627 "SerializableTest.c"
	} else {
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp1_ = FALSE;
#line 1631 "SerializableTest.c"
	}
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp1_) {
#line 1635 "SerializableTest.c"
		SerializableBanana* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		SerializableBanana* _tmp17_ = NULL;
		gint _tmp18_ = 0;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp15_ = a;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp16_ = _tmp15_->priv->_public_property;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp17_ = b;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp18_ = _tmp17_->priv->_public_property;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp0_ = _tmp16_ == _tmp18_;
#line 1650 "SerializableTest.c"
	} else {
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp0_ = FALSE;
#line 1654 "SerializableTest.c"
	}
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 1660 "SerializableTest.c"
}


static GParamSpec** serializable_banana_real_list_serializable_properties (GXmlSerializableObjectModel* base, int* result_length1) {
	SerializableBanana * self;
	GParamSpec** result = NULL;
	GParamSpec** properties = NULL;
	GParamSpec** _tmp0_ = NULL;
	gint properties_length1 = 0;
	gint _properties_size_ = 0;
	gint i = 0;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	GParamSpec** _tmp15_ = NULL;
	gint _tmp15__length1 = 0;
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableBanana*) base;
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = g_new0 (GParamSpec*, 4 + 1);
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	properties = _tmp0_;
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	properties_length1 = 4;
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_properties_size_ = properties_length1;
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	i = 0;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = g_strdup ("private-field");
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = g_strdup ("public-field");
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = g_strdup ("private-property");
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = g_strdup ("public-property");
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_ = g_new0 (gchar*, 4 + 1);
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_[0] = _tmp1_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_[1] = _tmp2_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_[2] = _tmp3_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_[3] = _tmp4_;
#line 1709 "SerializableTest.c"
	{
		gchar** name_collection = NULL;
		gint name_collection_length1 = 0;
		gint _name_collection_size_ = 0;
		gint name_it = 0;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		name_collection = _tmp5_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		name_collection_length1 = 4;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		for (name_it = 0; name_it < 4; name_it = name_it + 1) {
#line 1721 "SerializableTest.c"
			gchar* _tmp6_ = NULL;
			gchar* name = NULL;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp6_ = g_strdup (name_collection[name_it]);
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			name = _tmp6_;
#line 1728 "SerializableTest.c"
			{
				GParamSpec** _tmp7_ = NULL;
				gint _tmp7__length1 = 0;
				gint _tmp8_ = 0;
				const gchar* _tmp9_ = NULL;
				const gchar* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				GParamSpecInt* _tmp12_ = NULL;
				GParamSpec* _tmp13_ = NULL;
				gint _tmp14_ = 0;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp7_ = properties;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp7__length1 = properties_length1;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp8_ = i;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp9_ = name;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp10_ = name;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp11_ = name;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp12_ = g_param_spec_int (_tmp9_, _tmp10_, _tmp11_, G_MININT, G_MAXINT, 0, G_PARAM_READABLE);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_g_param_spec_unref0 (_tmp7_[_tmp8_]);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp7_[_tmp8_] = G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, G_TYPE_PARAM, GParamSpec);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp13_ = _tmp7_[_tmp8_];
#line 164 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp14_ = i;
#line 164 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				i = _tmp14_ + 1;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_g_free0 (name);
#line 1765 "SerializableTest.c"
			}
		}
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 1770 "SerializableTest.c"
	}
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp15_ = properties;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp15__length1 = properties_length1;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (result_length1) {
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		*result_length1 = _tmp15__length1;
#line 1780 "SerializableTest.c"
	}
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp15_;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 1786 "SerializableTest.c"
}


void serializable_banana_get_property_value (SerializableBanana* self, GParamSpec* spec, GValue* val) {
	GValue _tmp0_ = {0};
	GValue _tmp1_ = {0};
	GParamSpec* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GQuark _tmp6_ = 0U;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp5_label0 = 0;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp5_label1 = 0;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp5_label2 = 0;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp5_label3 = 0;
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (spec != NULL);
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (val != NULL);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_value_init (&_tmp0_, G_TYPE_INT);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_IS_VALUE (val) ? (g_value_unset (val), NULL) : NULL;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	*val = _tmp0_;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = *val;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = spec;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = _tmp2_->name;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = _tmp3_;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp6_ = (NULL == _tmp4_) ? 0 : g_quark_from_string (_tmp4_);
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp6_ == ((0 != _tmp5_label0) ? _tmp5_label0 : (_tmp5_label0 = g_quark_from_static_string ("private-field")))) {
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1831 "SerializableTest.c"
			default:
			{
				gint _tmp7_ = 0;
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp7_ = self->priv->private_field;
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				g_value_set_int (val, _tmp7_);
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 1841 "SerializableTest.c"
			}
		}
	} else if (_tmp6_ == ((0 != _tmp5_label1) ? _tmp5_label1 : (_tmp5_label1 = g_quark_from_static_string ("public-field")))) {
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1847 "SerializableTest.c"
			default:
			{
				gint _tmp8_ = 0;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp8_ = self->public_field;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				g_value_set_int (val, _tmp8_);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 1857 "SerializableTest.c"
			}
		}
	} else if (_tmp6_ == ((0 != _tmp5_label2) ? _tmp5_label2 : (_tmp5_label2 = g_quark_from_static_string ("private-property")))) {
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1863 "SerializableTest.c"
			default:
			{
				gint _tmp9_ = 0;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp9_ = self->priv->_private_property;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				g_value_set_int (val, _tmp9_);
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 1873 "SerializableTest.c"
			}
		}
	} else if (_tmp6_ == ((0 != _tmp5_label3) ? _tmp5_label3 : (_tmp5_label3 = g_quark_from_static_string ("public-property")))) {
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1879 "SerializableTest.c"
			default:
			{
				gint _tmp10_ = 0;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp10_ = self->priv->_public_property;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				g_value_set_int (val, _tmp10_);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 1889 "SerializableTest.c"
			}
		}
	} else {
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1895 "SerializableTest.c"
			default:
			{
				GParamSpec* _tmp11_ = NULL;
				const gchar* _tmp12_ = NULL;
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp11_ = spec;
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp12_ = _tmp11_->name;
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				g_object_get_property (G_TYPE_CHECK_INSTANCE_CAST (self, G_TYPE_OBJECT, GObject), _tmp12_, val);
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				return;
#line 1908 "SerializableTest.c"
			}
		}
	}
}


void serializable_banana_set_property_value (SerializableBanana* self, GParamSpec* spec, GValue* val) {
	GParamSpec* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GQuark _tmp4_ = 0U;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp3_label0 = 0;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp3_label1 = 0;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp3_label2 = 0;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	static GQuark _tmp3_label3 = 0;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (spec != NULL);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (val != NULL);
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = spec;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = _tmp0_->name;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = _tmp1_;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = (NULL == _tmp2_) ? 0 : g_quark_from_string (_tmp2_);
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (_tmp4_ == ((0 != _tmp3_label0) ? _tmp3_label0 : (_tmp3_label0 = g_quark_from_static_string ("private-field")))) {
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1946 "SerializableTest.c"
			default:
			{
				gint _tmp5_ = 0;
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp5_ = g_value_get_int (val);
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				self->priv->private_field = _tmp5_;
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 1956 "SerializableTest.c"
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label1) ? _tmp3_label1 : (_tmp3_label1 = g_quark_from_static_string ("public-field")))) {
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1962 "SerializableTest.c"
			default:
			{
				gint _tmp6_ = 0;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp6_ = g_value_get_int (val);
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				self->public_field = _tmp6_;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 1972 "SerializableTest.c"
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label2) ? _tmp3_label2 : (_tmp3_label2 = g_quark_from_static_string ("private-property")))) {
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1978 "SerializableTest.c"
			default:
			{
				gint _tmp7_ = 0;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp7_ = g_value_get_int (val);
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				serializable_banana_set_private_property (self, _tmp7_);
#line 204 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 1988 "SerializableTest.c"
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label3) ? _tmp3_label3 : (_tmp3_label3 = g_quark_from_static_string ("public-property")))) {
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 1994 "SerializableTest.c"
			default:
			{
				gint _tmp8_ = 0;
#line 206 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp8_ = g_value_get_int (val);
#line 206 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				serializable_banana_set_public_property (self, _tmp8_);
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				break;
#line 2004 "SerializableTest.c"
			}
		}
	} else {
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		switch (0) {
#line 2010 "SerializableTest.c"
			default:
			{
				GParamSpec* _tmp9_ = NULL;
				const gchar* _tmp10_ = NULL;
				GValue _tmp11_ = {0};
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp9_ = spec;
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp10_ = _tmp9_->name;
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				_tmp11_ = *val;
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				g_object_set_property (G_TYPE_CHECK_INSTANCE_CAST (self, G_TYPE_OBJECT, GObject), _tmp10_, &_tmp11_);
#line 210 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
				return;
#line 2026 "SerializableTest.c"
			}
		}
	}
}


static gint serializable_banana_get_private_property (SerializableBanana* self) {
	gint result;
	gint _tmp0_ = 0;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->_private_property;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 2044 "SerializableTest.c"
}


static void serializable_banana_set_private_property (SerializableBanana* self, gint value) {
	gint _tmp0_ = 0;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = value;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->_private_property = _tmp0_;
#line 2056 "SerializableTest.c"
}


gint serializable_banana_get_public_property (SerializableBanana* self) {
	gint result;
	gint _tmp0_ = 0;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = self->priv->_public_property;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	result = _tmp0_;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return result;
#line 2071 "SerializableTest.c"
}


void serializable_banana_set_public_property (SerializableBanana* self, gint value) {
	gint _tmp0_ = 0;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_return_if_fail (self != NULL);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = value;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv->_public_property = _tmp0_;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_notify ((GObject *) self, "public-property");
#line 2085 "SerializableTest.c"
}


static void serializable_banana_class_init (SerializableBananaClass * klass) {
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_banana_parent_class = g_type_class_peek_parent (klass);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_type_class_add_private (klass, sizeof (SerializableBananaPrivate));
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*)(GXmlSerializableObjectModel*)) serializable_banana_real_property_use_nick;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_banana_real_node_name;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_banana_real_to_string;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->list_serializable_properties = (GParamSpec** (*)(GXmlSerializableObjectModel*, int*)) serializable_banana_real_list_serializable_properties;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_banana_get_property;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_banana_set_property;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_banana_finalize;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BANANA_PUBLIC_PROPERTY, g_param_spec_int ("public-property", "PublicProperty", "public-property", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2110 "SerializableTest.c"
}


static void serializable_banana_instance_init (SerializableBanana * self) {
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self->priv = SERIALIZABLE_BANANA_GET_PRIVATE (self);
#line 2117 "SerializableTest.c"
}


static void serializable_banana_finalize (GObject* obj) {
	SerializableBanana * self;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SERIALIZABLE_BANANA, SerializableBanana);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	G_OBJECT_CLASS (serializable_banana_parent_class)->finalize (obj);
#line 2127 "SerializableTest.c"
}


GType serializable_banana_get_type (void) {
	static volatile gsize serializable_banana_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_banana_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableBananaClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_banana_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableBanana), 0, (GInstanceInitFunc) serializable_banana_instance_init, NULL };
		GType serializable_banana_type_id;
		serializable_banana_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableBanana", &g_define_type_info, 0);
		g_once_init_leave (&serializable_banana_type_id__volatile, serializable_banana_type_id);
	}
	return serializable_banana_type_id__volatile;
}


static void _vala_serializable_banana_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SerializableBanana * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SERIALIZABLE_BANANA, SerializableBanana);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	switch (property_id) {
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_BANANA_PUBLIC_PROPERTY:
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_value_set_int (value, serializable_banana_get_public_property (self));
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 2154 "SerializableTest.c"
		default:
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 2160 "SerializableTest.c"
	}
}


static void _vala_serializable_banana_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SerializableBanana * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SERIALIZABLE_BANANA, SerializableBanana);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	switch (property_id) {
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		case SERIALIZABLE_BANANA_PUBLIC_PROPERTY:
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		serializable_banana_set_public_property (self, g_value_get_int (value));
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 2176 "SerializableTest.c"
		default:
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		break;
#line 2182 "SerializableTest.c"
	}
}


static void __lambda6_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializableTomato* tomato = NULL;
		SerializableTomato* _tmp0_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		SerializableTomato* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		SerializableTomato* tomato2 = NULL;
		SerializableTomato* _tmp6_ = NULL;
		SerializableTomato* _tmp7_ = NULL;
		GXmlGDocument* _tmp8_ = NULL;
		SerializableTomato* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		SerializableTomato* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		SerializableTomato* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		SerializableTomato* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		SerializableTomato* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		gint _tmp20_ = 0;
		SerializableTomato* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		SerializableTomato* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
#line 219 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp0_ = serializable_tomato_new (0, 0, 12, "cats");
#line 219 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		tomato = _tmp0_;
#line 220 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 220 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		doc = _tmp1_;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp2_ = tomato;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp3_ = doc;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp5_ = _tmp4_;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (_tmp5_);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (doc);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (tomato);
#line 2244 "SerializableTest.c"
			goto __catch9_g_error;
		}
#line 222 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp6_ = serializable_tomato_new (1, 1, 4, "dogs");
#line 222 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		tomato2 = _tmp6_;
#line 223 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp7_ = tomato2;
#line 223 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp8_ = doc;
#line 223 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp7_, (GXmlNode*) _tmp8_, &_inner_error_);
#line 223 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 223 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (tomato2);
#line 223 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (doc);
#line 223 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (tomato);
#line 2265 "SerializableTest.c"
			goto __catch9_g_error;
		}
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp9_ = tomato;
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp10_ = _tmp9_->weight;
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp11_ = tomato2;
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp12_ = _tmp11_->weight;
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_vala_assert (_tmp10_ != _tmp12_, "tomato.weight != tomato2.weight");
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp13_ = tomato2;
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp14_ = _tmp13_->weight;
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_vala_assert (_tmp14_ == 1, "tomato2.weight == 1");
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp15_ = tomato;
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp16_ = serializable_tomato_get_height (_tmp15_);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp17_ = _tmp16_;
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp18_ = tomato2;
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp19_ = serializable_tomato_get_height (_tmp18_);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp20_ = _tmp19_;
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_vala_assert (_tmp17_ == _tmp20_, "tomato.height == tomato2.height");
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp21_ = tomato;
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp22_ = serializable_tomato_get_description (_tmp21_);
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp23_ = _tmp22_;
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp24_ = tomato2;
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp25_ = serializable_tomato_get_description (_tmp24_);
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp26_ = _tmp25_;
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, _tmp26_) == 0, "tomato.description == tomato2.description");
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (tomato2);
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (doc);
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (tomato);
#line 2318 "SerializableTest.c"
	}
	goto __finally9;
	__catch9_g_error:
	{
		GError* e = NULL;
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		e = _inner_error_;
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_inner_error_ = NULL;
#line 232 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_assert_not_reached ();
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_error_free0 (e);
#line 2332 "SerializableTest.c"
	}
	__finally9:
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_clear_error (&_inner_error_);
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		return;
#line 2343 "SerializableTest.c"
	}
}


static void ___lambda6__gtest_func (void) {
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	__lambda6_ ();
#line 2351 "SerializableTest.c"
}


static void __lambda7_ (void) {
	GXmlDocument* doc = NULL;
	SerializableCapsicum* capsicum = NULL;
	SerializableCapsicum* capsicum_new = NULL;
	gchar* expectation = NULL;
	GRegex* regex = NULL;
	GList* ratings = NULL;
	SerializableCapsicum* _tmp0_ = NULL;
	gchar* _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_list_free0 (ratings);
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	ratings = NULL;
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	ratings = g_list_append (ratings, (gpointer) ((gintptr) 8));
#line 245 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	ratings = g_list_append (ratings, (gpointer) ((gintptr) 13));
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	ratings = g_list_append (ratings, (gpointer) ((gintptr) 21));
#line 248 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = serializable_capsicum_new (2, 3, 6, ratings);
#line 248 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_object_unref0 (capsicum);
#line 248 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	capsicum = _tmp0_;
#line 2381 "SerializableTest.c"
	{
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
#line 250 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 250 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (doc);
#line 250 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		doc = (GXmlDocument*) _tmp1_;
#line 251 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) capsicum, (GXmlNode*) doc, &_inner_error_);
#line 251 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp3_ = _tmp2_;
#line 251 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (_tmp3_);
#line 251 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2400 "SerializableTest.c"
			goto __catch10_g_error;
		}
	}
	goto __finally10;
	__catch10_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp4_ = NULL;
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		e = _inner_error_;
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_inner_error_ = NULL;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp4_ = e->message;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_message ("SerializableTest.vala:253: %s", _tmp4_);
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_assert_not_reached ();
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_error_free0 (e);
#line 2421 "SerializableTest.c"
	}
	__finally10:
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_list_free0 (ratings);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_regex_unref0 (regex);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_free0 (expectation);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (capsicum_new);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (capsicum);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (doc);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_clear_error (&_inner_error_);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		return;
#line 2444 "SerializableTest.c"
	}
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp5_ = g_strdup ("<\\?xml version=\"1.0\"\\?>\n<");
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_free0 (expectation);
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	expectation = _tmp5_;
#line 2452 "SerializableTest.c"
	{
		GRegex* _tmp6_ = NULL;
		GRegex* _tmp7_ = NULL;
		GRegex* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gboolean _tmp11_ = FALSE;
		gboolean _tmp12_ = FALSE;
		gboolean _tmp18_ = FALSE;
		gboolean _tmp19_ = FALSE;
		gboolean _tmp20_ = FALSE;
		gint _tmp21_ = 0;
		gint _tmp22_ = 0;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp7_ = g_regex_new (expectation, 0, 0, &_inner_error_);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp6_ = _tmp7_;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 2474 "SerializableTest.c"
				goto __catch11_g_regex_error;
			}
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_list_free0 (ratings);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_regex_unref0 (regex);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_free0 (expectation);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (capsicum_new);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (capsicum);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (doc);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_clear_error (&_inner_error_);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			return;
#line 2495 "SerializableTest.c"
		}
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp8_ = _tmp6_;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp6_ = NULL;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_regex_unref0 (regex);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		regex = _tmp8_;
#line 261 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp9_ = gxml_gnode_to_string ((GXmlGNode*) (G_TYPE_CHECK_INSTANCE_TYPE (doc, GXML_TYPE_GDOCUMENT) ? ((GXmlGDocument*) doc) : NULL));
#line 261 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp10_ = _tmp9_;
#line 261 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp11_ = g_regex_match (regex, _tmp10_, 0, NULL);
#line 261 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp12_ = !_tmp11_;
#line 261 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_free0 (_tmp10_);
#line 261 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (_tmp12_) {
#line 2517 "SerializableTest.c"
			gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
#line 262 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp13_ = gxml_node_to_string ((GXmlNode*) doc);
#line 262 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp14_ = _tmp13_;
#line 262 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_test_message ("Did not serialize as expected.  Got [%s] but expected [%s]", _tmp14_, expectation);
#line 262 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_free0 (_tmp14_);
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_assert_not_reached ();
#line 2530 "SerializableTest.c"
		}
		{
			GList* _tmp15_ = NULL;
			SerializableCapsicum* _tmp16_ = NULL;
#line 267 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp15_ = NULL;
#line 267 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp16_ = serializable_capsicum_new (1, 1, 1, _tmp15_);
#line 267 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (capsicum_new);
#line 267 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			capsicum_new = _tmp16_;
#line 267 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_list_free0 (_tmp15_);
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) capsicum_new, (GXmlNode*) doc, &_inner_error_);
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2549 "SerializableTest.c"
				goto __catch12_g_error;
			}
		}
		goto __finally12;
		__catch12_g_error:
		{
			GError* e = NULL;
			const gchar* _tmp17_ = NULL;
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			e = _inner_error_;
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_inner_error_ = NULL;
#line 270 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp17_ = e->message;
#line 270 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_test_message ("%s", _tmp17_);
#line 271 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_assert_not_reached ();
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_error_free0 (e);
#line 2570 "SerializableTest.c"
		}
		__finally12:
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_regex_unref0 (_tmp6_);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 2579 "SerializableTest.c"
				goto __catch11_g_regex_error;
			}
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_regex_unref0 (_tmp6_);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_list_free0 (ratings);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_regex_unref0 (regex);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_free0 (expectation);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (capsicum_new);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (capsicum);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_object_unref0 (doc);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_clear_error (&_inner_error_);
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			return;
#line 2602 "SerializableTest.c"
		}
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp21_ = serializable_capsicum_get_height (capsicum_new);
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp22_ = _tmp21_;
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (_tmp22_ != 6) {
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp20_ = TRUE;
#line 2612 "SerializableTest.c"
		} else {
			guint _tmp23_ = 0U;
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp23_ = g_list_length (ratings);
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp20_ = _tmp23_ != ((guint) 3);
#line 2619 "SerializableTest.c"
		}
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (_tmp20_) {
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp19_ = TRUE;
#line 2625 "SerializableTest.c"
		} else {
			gconstpointer _tmp24_ = NULL;
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp24_ = g_list_nth_data (ratings, (guint) 0);
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp19_ = ((gint) ((gintptr) _tmp24_)) != 8;
#line 2632 "SerializableTest.c"
		}
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (_tmp19_) {
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp18_ = TRUE;
#line 2638 "SerializableTest.c"
		} else {
			gconstpointer _tmp25_ = NULL;
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp25_ = g_list_nth_data (ratings, (guint) 2);
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp18_ = ((gint) ((gintptr) _tmp25_)) != 21;
#line 2645 "SerializableTest.c"
		}
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		if (_tmp18_) {
#line 2649 "SerializableTest.c"
			gchar* _tmp26_ = NULL;
			gchar* _tmp27_ = NULL;
			gchar* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
			guint _tmp30_ = 0U;
			gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp26_ = gxml_serializable_object_model_to_string ((GXmlSerializableObjectModel*) capsicum_new);
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp27_ = _tmp26_;
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp28_ = gxml_serializable_object_model_to_string ((GXmlSerializableObjectModel*) capsicum);
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp29_ = _tmp28_;
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp30_ = g_list_length (ratings);
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp31_ = g_strdup_printf ("%u", _tmp30_);
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_tmp32_ = _tmp31_;
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_test_message ("Did not deserialize as expected.  Got [%s] but expected height and rat" \
"ings from [%s], length: %s", _tmp27_, _tmp29_, _tmp32_);
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_free0 (_tmp32_);
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_free0 (_tmp29_);
#line 274 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			_g_free0 (_tmp27_);
#line 275 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
			g_assert_not_reached ();
#line 2681 "SerializableTest.c"
		}
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_regex_unref0 (_tmp6_);
#line 2685 "SerializableTest.c"
	}
	goto __finally11;
	__catch11_g_regex_error:
	{
		GError* e = NULL;
		const gchar* _tmp33_ = NULL;
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		e = _inner_error_;
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_inner_error_ = NULL;
#line 278 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_tmp33_ = e->message;
#line 278 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_test_message ("Regular expression [%s] for test failed: %s", expectation, _tmp33_);
#line 280 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_assert_not_reached ();
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_error_free0 (e);
#line 2704 "SerializableTest.c"
	}
	__finally11:
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_list_free0 (ratings);
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_regex_unref0 (regex);
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_free0 (expectation);
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (capsicum_new);
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (capsicum);
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		_g_object_unref0 (doc);
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		g_clear_error (&_inner_error_);
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
		return;
#line 2727 "SerializableTest.c"
	}
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_list_free0 (ratings);
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_regex_unref0 (regex);
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_free0 (expectation);
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_object_unref0 (capsicum_new);
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_object_unref0 (capsicum);
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_object_unref0 (doc);
#line 2741 "SerializableTest.c"
}


static void ___lambda7__gtest_func (void) {
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	__lambda7_ ();
#line 2748 "SerializableTest.c"
}


static void __lambda8_ (void) {
	SerializableBanana* banana = NULL;
	SerializableBanana* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp0_ = serializable_banana_new (17, 19, 23, 29);
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	banana = _tmp0_;
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp1_ = gxml_serializable_object_model_to_string ((GXmlSerializableObjectModel*) banana);
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp2_ = _tmp1_;
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp3_ = g_strconcat ("Banana:", _tmp2_, NULL);
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_tmp4_ = _tmp3_;
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_test_message ("%s", _tmp4_);
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_free0 (_tmp4_);
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_free0 (_tmp2_);
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	_g_object_unref0 (banana);
#line 2779 "SerializableTest.c"
}


static void ___lambda8__gtest_func (void) {
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	__lambda8_ ();
#line 2786 "SerializableTest.c"
}


void serializable_test_add_tests (void) {
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_test_add_func ("/gxml/serializable/interface_defaults", ___lambda6__gtest_func);
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_test_add_func ("/gxml/serializable/interface_override_serialization_on_list", ___lambda7__gtest_func);
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	g_test_add_func ("/gxml/serializable/interface_override_properties_view", ___lambda8__gtest_func);
#line 2797 "SerializableTest.c"
}


SerializableTest* serializable_test_construct (GType object_type) {
	SerializableTest* self = NULL;
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	self = (SerializableTest*) gxml_test_construct (object_type);
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return self;
#line 2807 "SerializableTest.c"
}


SerializableTest* serializable_test_new (void) {
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	return serializable_test_construct (TYPE_SERIALIZABLE_TEST);
#line 2814 "SerializableTest.c"
}


static void serializable_test_class_init (SerializableTestClass * klass) {
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializableTest.vala"
	serializable_test_parent_class = g_type_class_peek_parent (klass);
#line 2821 "SerializableTest.c"
}


static void serializable_test_instance_init (SerializableTest * self) {
}


GType serializable_test_get_type (void) {
	static volatile gsize serializable_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableTest), 0, (GInstanceInitFunc) serializable_test_instance_init, NULL };
		GType serializable_test_type_id;
		serializable_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_test_type_id__volatile, serializable_test_type_id);
	}
	return serializable_test_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



